@@ -40,6 +40,7 @@ static SCM _in_construction_from_scheme;
 static GQuark quark_guile_gtype_class = 0;
 
 SCM_SYMBOL  (sym_gruntime_error,"gruntime-error");
+SCM_KEYWORD (kw_init_keyword, "init-keyword");
 
 /* #define DEBUG_PRINT */
 
@@ -115,7 +116,8 @@ is_init_keyword (SCM slots, SCM kw)
     for (; SCM_CONSP (slots); slots = scm_cdr (slots))
         for (defs = scm_cdar (slots); SCM_CONSP (defs);
              defs = scm_cddr (defs))
-            if (scm_is_eq (scm_car (defs), kw))
+            if (scm_is_eq (scm_car (defs), kw_init_keyword)
+                && scm_is_eq (scm_cadr (defs), kw))
                 return TRUE;
 
     return FALSE;
@@ -390,8 +392,7 @@ SCM_DEFINE (scm_gobject_class_get_properties, "gobject-class-get-properties", 1,
 {
     gpointer gclass = 0;
     GParamSpec **properties;
-    guint n_properties;
-    glong i;
+    guint n_properties, i;
     GType gtype;
     SCM ret = SCM_EOL;
 
@@ -412,8 +413,8 @@ SCM_DEFINE (scm_gobject_class_get_properties, "gobject-class-get-properties", 1,
         scm_wrong_type_arg (FUNC_NAME, 1, class);
     }
 
-    for (i = n_properties - 1; i >= 0; i--)
-        ret = scm_cons (scm_c_gtype_instance_to_scm (properties[i]),
+    for (i = n_properties; i > 0; i--)
+        ret = scm_cons (scm_c_gtype_instance_to_scm (properties[i-1]),
                         ret);
 
     if (G_TYPE_FUNDAMENTAL (gtype) == G_TYPE_OBJECT)
@@ -435,8 +436,7 @@ SCM_DEFINE (scm_gobject_class_get_property_names, "gobject-class-get-property-na
 {
     gpointer gclass = 0;
     GParamSpec **properties;
-    guint n_properties;
-    glong i;
+    guint n_properties, i;
     GType gtype;
     SCM ret = SCM_EOL;
 
@@ -457,8 +457,8 @@ SCM_DEFINE (scm_gobject_class_get_property_names, "gobject-class-get-property-na
         scm_wrong_type_arg (FUNC_NAME, 1, class);
     }
 
-    for (i = n_properties - 1; i >= 0; i--)
-        ret = scm_cons (scm_from_locale_symbol (properties[i]->name), ret);
+    for (i = n_properties; i > 0; i--)
+        ret = scm_cons (scm_from_locale_symbol (properties[i-1]->name), ret);
 
     if (G_TYPE_FUNDAMENTAL (gtype) == G_TYPE_OBJECT)
         g_type_class_unref (gclass);
@@ -665,6 +665,14 @@ SCM_DEFINE (scm_sys_gnome_gobject_object_post_init,
 }
 #undef FUNC_NAME
 
+static void
+sink_initially_unowned (gpointer i)
+{
+    GObject *object = i;
+    if (g_object_is_floating (object))
+        g_object_ref_sink (object);
+}
+
 void
 scm_init_gnome_gobject (void)
 {
@@ -684,5 +692,8 @@ scm_init_gnome_gobject (void)
     _in_construction_from_scheme = scm_permanent_object (scm_make_fluid ());
     scm_fluid_set_x (_in_construction_from_scheme, SCM_EOL);
 
+    scm_register_gtype_instance_sinkfunc (G_TYPE_INITIALLY_UNOWNED,
+                                          sink_initially_unowned);
+
     quark_guile_gtype_class = g_quark_from_static_string ("%scm-guile-gtype-class");
 }
