@@ -166,7 +166,7 @@ scm_c_register_gvalue_wrappers (GType type,
     w->wrap = wrap;
     w->unwrap = unwrap;
 
-    g_hash_table_insert (gvalue_wrappers, GINT_TO_POINTER (type), w);
+    g_hash_table_insert (gvalue_wrappers, (gpointer)type, w);
 }
 
 void
@@ -181,7 +181,7 @@ scm_c_register_gtype_instance_gvalue_wrappers (GType type,
     w->getter = getter;
     w->setter = setter;
     
-    g_hash_table_insert (gtype_instance_wrappers, GINT_TO_POINTER (type), w);
+    g_hash_table_insert (gtype_instance_wrappers, (gpointer)type, w);
 }
 
 SCM
@@ -238,10 +238,10 @@ scm_c_gvalue_ref (const GValue *gvalue)
             gtype_instance_wrap_funcs* w1;
             wrap_funcs* w2;
             if ((w1 = g_hash_table_lookup (gtype_instance_wrappers,
-                                           GINT_TO_POINTER (fundamental)))) {
+                                           (gpointer)fundamental))) {
                 return scm_c_gtype_instance_to_scm (w1->getter (gvalue));
             } else if ((w2 = g_hash_table_lookup (gvalue_wrappers,
-                                                  GINT_TO_POINTER (type)))) {
+                                                  (gpointer)type))) {
                 return w2->wrap (gvalue);
             } else {
                 SCM ret = scm_c_make_gvalue (type);
@@ -281,13 +281,25 @@ scm_c_gvalue_set (GValue *gvalue, SCM value)
     
     switch (fundamental) {
     case G_TYPE_CHAR:
-	SCM_VALIDATE_CHAR (2, value);
-	g_value_set_char (gvalue, SCM_CHAR (value));
+        if (SCM_CHARP (value))
+            g_value_set_char (gvalue, SCM_CHAR (value));
+        else if (SCM_INUMP (value)
+                 && SCM_INUM (value) >= 0 && SCM_INUM (value) <= 127)
+            g_value_set_char (gvalue, SCM_INUM (value));
+        else
+            scm_c_gruntime_error (FUNC_NAME, "Bad char value: ~A",
+                                  SCM_LIST1 (value));
 	break;
 
     case G_TYPE_UCHAR:
-	SCM_VALIDATE_CHAR (2, value);
-	g_value_set_uchar (gvalue, SCM_CHAR (value));
+        if (SCM_CHARP (value))
+            g_value_set_uchar (gvalue, SCM_CHAR (value));
+        else if (SCM_INUMP (value)
+                 && SCM_INUM (value) >= 0 && SCM_INUM (value) <= 255)
+            g_value_set_uchar (gvalue, SCM_INUM (value));
+        else
+            scm_c_gruntime_error (FUNC_NAME, "Bad uchar value: ~A",
+                                  SCM_LIST1 (value));
 	break;
 
     case G_TYPE_BOOLEAN:
@@ -357,7 +369,7 @@ scm_c_gvalue_set (GValue *gvalue, SCM value)
         {
             gtype_instance_wrap_funcs *w;
             w = g_hash_table_lookup (gtype_instance_wrappers,
-                                     GINT_TO_POINTER (fundamental));
+                                     (gpointer)fundamental);
 
             if (w) {
                 if (SCM_FALSEP (value)) {
@@ -376,8 +388,7 @@ scm_c_gvalue_set (GValue *gvalue, SCM value)
         }
         {
             wrap_funcs *w;
-            w = g_hash_table_lookup (gvalue_wrappers,
-                                     GINT_TO_POINTER (gtype));
+            w = g_hash_table_lookup (gvalue_wrappers, (gpointer)gtype);
     
             if (w) {
                 w->unwrap (value, gvalue);
